==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WaterfallSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { WaterfallSeriesDescription } from "./WaterfallSeriesDescription";
/**
 * @hidden
 */
export let WaterfallSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class WaterfallSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (WaterfallSeriesDescriptionMetadata.a == null) {
                WaterfallSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WaterfallSeriesDescriptionMetadata.c(WaterfallSeriesDescriptionMetadata.a);
            }
            if (a.j(WaterfallSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(WaterfallSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("NegativeBrush", "Brush");
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
            a.item("NegativeOutline", "Brush");
        }
        static d(a) {
            WaterfallSeriesDescriptionMetadata.b(a);
            a.aa("WaterfallSeries", () => new WaterfallSeriesDescription());
            a.z("WaterfallSeries", WaterfallSeriesDescriptionMetadata.a);
        }
    }
    WaterfallSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(WaterfallSeriesDescriptionMetadata, 'WaterfallSeriesDescriptionMetadata');
    WaterfallSeriesDescriptionMetadata.a = null;
    return WaterfallSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WaterfallSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { WaterfallSeriesDescription } from "./WaterfallSeriesDescription";
/**
 * @hidden
 */
export let WaterfallSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class WaterfallSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (WaterfallSeriesDescriptionMetadata.a == null) {
                WaterfallSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WaterfallSeriesDescriptionMetadata.c(WaterfallSeriesDescriptionMetadata.a);
            }
            if (a.k(WaterfallSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(WaterfallSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("NegativeBrush", "Brush");
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
            a.item("NegativeOutline", "Brush");
        }
        static d(a) {
            WaterfallSeriesDescriptionMetadata.b(a);
            a.ac("WaterfallSeries", () => new WaterfallSeriesDescription());
            a.ab("WaterfallSeries", WaterfallSeriesDescriptionMetadata.a);
        }
    }
    WaterfallSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(WaterfallSeriesDescriptionMetadata, 'WaterfallSeriesDescriptionMetadata');
    WaterfallSeriesDescriptionMetadata.a = null;
    return WaterfallSeriesDescriptionMetadata;
})();
